@@ -4,9 +4,14 @@
 #' a character vector.  The default is to use \code{"\\b"} for left and right 
 #' boundaries.
 #' 
-#' @param x A character vector.
+#' @param \ldots Regular expressions to add grouping parenthesis to a named 
+#' expression from the default regular expression dictionary prefixed with 
+#' single at (\code{@@}) (e.g., \code{"@@rm_hash"}) or a regular expression from 
+#' \code{\link[qdapRegex]{regex_supplement}} dictionary prefixed with an at 
+#' (\code{@@}) (e.g., \code{"@@time_12_hours"}).
 #' @param left A single length character vector to use as the left bound.
 #' @param right A single length character vector to use as the right bound.
+#' @param dictionary A dictionary of canned regular expressions to search within.
 #' @return Returns a character vector.
 #' @export
 #' @seealso \code{\link[base]{paste0}}
@@ -25,9 +30,13 @@
 #'     "I", "at", "be", "this", "have", "from")
 #' 
 #' gsub(pastex(list(bind(Fry25))), "[[ELIM]]", x)
-bind <- function(x, left="\\b", right = left){
-
-    paste0(left, x, right)
+bind <- function(..., left="\\b", right = left, 
+    dictionary = getOption("regex.library")){
+    out <- lapply(list(...), function(x) {
+        if (length(x) > 1) return(x)
+        reg_check(x, dictionary = dictionary)
+    })
+    paste0(left, unlist(out), right)
 
 }
 
